@@ -100,8 +100,9 @@ class VenmoRulesEngine(domain.RulesEngine, ff.SystemBusAware):
 
             @bra.rule_action(params={'command': FIELD_TEXT})
             def invoke_command(self, command: str, params: dict):
-                params.update(self.data)
-                self._system_bus.invoke(command, params)
+                p = params.copy()
+                p.update(self.data)
+                self._system_bus.invoke(command, p)
 
         Actions._system_bus = self._system_bus
         self._action_object = Actions
